package de.fraunhofer.iem.dataprovider.kpi.entity

import de.fraunhofer.iem.dataprovider.kpi.dto.KpiCalculationDto
import de.fraunhofer.iem.dataprovider.kpi.enumeration.KpiKind
import de.fraunhofer.iem.dataprovider.kpi.strategy.RawValueKPICalculationStrategy
import de.fraunhofer.iem.dataprovider.repository.entity.RepositoryEntity
import jakarta.persistence.*
import org.hibernate.annotations.JdbcTypeCode
import org.hibernate.type.SqlTypes
import java.sql.Timestamp
import java.util.*

@Entity
@Table(name = "kpi")
class KPIEntity(
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id", nullable = false)
    var id: UUID? = null,

    @ManyToOne(optional = false)
    @JoinColumn(name = "repository_id")
    val repository: RepositoryEntity,

    @Column(name = "score", nullable = false)
    val score: Int,

    @Enumerated(EnumType.STRING)
    var kind: KpiKind,

    @JdbcTypeCode(SqlTypes.TIMESTAMP)
    @Column(name = "timestamp")
    var timestamp: Timestamp? = null
) {

    fun toCalculationDto(): KpiCalculationDto {
        return KpiCalculationDto(
            kind = this.kind,
            calculationStrategy = RawValueKPICalculationStrategy(this.score),
            isEmpty = false
        )
    }
}
